@@ -206,10 +206,16 @@ scoreMarkers <- function(
     min.rank.limit=500,
     num.threads=1
 ) {
+    .checkSEX(x, "scoreMarkers.se")
+
     rn <- rownames(x)
     ngenes <- nrow(x)
     x <- initializeCpp(x, .check.na=FALSE)
+
     groups <- .transformFactor(groups)
+    if (is.null(groups$index)) {
+        stop("'groups' should be non-NULL")
+    }
     block <- .transformFactor(block)
 
     args <- list(
