@@ -1,11 +1,10 @@
-//#include "config.h"
+#include "config.h"
 
 #include <vector>
 #include <stdexcept>
 
-#include "Rcpp.h"
-
 #include "scran_markers/scran_markers.hpp"
+#include "sanisizer/sanisizer.hpp"
 
 #include "utils_markers.h"
 
@@ -22,14 +21,14 @@ SEXP summarize_effects(
     bool compute_summary_min_rank,
     int num_threads
 ) {
-    const std::size_t expected = sanisizer::product<std::size_t>(num_groups, num_groups, num_genes);
+    const auto expected = sanisizer::product<std::size_t>(num_groups, num_groups, num_genes);
     if (!sanisizer::is_equal(effects.size(), expected)) {
         throw std::runtime_error("'effects' does not have the expected length");
     }
 
     scran_markers::SummarizeEffectsOptions opt;
     opt.num_threads = num_threads;
-    const std::size_t num_quantiles = setup_quantile_options(compute_summary_quantiles, opt.compute_quantiles);
+    const auto num_quantiles = setup_quantile_options(compute_summary_quantiles, opt.compute_quantiles);
 
     std::vector<Rcpp::NumericVector> min, mean, median, max;
     std::vector<std::vector<Rcpp::NumericVector> > quant;
@@ -54,7 +53,13 @@ SEXP summarize_effects(
         mr
     );
 
-    scran_markers::summarize_effects(num_genes, num_groups, static_cast<const double*>(effects.begin()), groupwise, opt);
+    scran_markers::summarize_effects(
+        num_genes,
+        num_groups,
+        static_cast<const double*>(effects.begin()),
+        groupwise,
+        opt
+    );
 
     return format_summary_output(
         num_groups,
@@ -66,8 +71,7 @@ SEXP summarize_effects(
         median,
         compute_summary_max,
         max,
-        num_quantiles,
-        opt.compute_quantiles,
+        opt.compute_quantiles.has_value(),
         quant,
         compute_summary_min_rank,
         mr
