@@ -12,6 +12,9 @@ test_that("clusterGraph.se works as expected", {
     sce2 <- clusterGraph.se(sce, resolution=2)
     expect_false(identical(sce$clusters, sce2$clusters))
 
+    scel <- clusterGraph.se(sce, method="leiden")
+    expect_false(identical(sce$clusters, scel$clusters))
+
     sce <- clusterGraph.se(sce, graph.name="graph", meta.name="cluster")
     expect_type(metadata(sce)$cluster, "list")
     expect_null(metadata(sce)$cluster$membership)
